@@ -1,41 +1,57 @@
 #!/usr/bin/env python
 
 import unittest
-import numbers, fractions
+import numbers
+import fractions
 
 import qsoptex
 
+from six import b, u
+
+
 class TestVariableType(unittest.TestCase):
     def test_variable_str(self):
-        '''Test that a variable of bytes type works'''
+        """Test that a variable of bytes type works"""
         self._problem = qsoptex.ExactProblem()
-        self._problem.add_variable(name=b'x')
+        self._problem.add_variable(name=b('x'))
 
     def test_variable_unicode(self):
-        '''Test that a variable of unicode type works'''
+        """Test that a variable of unicode type works"""
         self._problem = qsoptex.ExactProblem()
-        self._problem.add_variable(name=u'x')
+        self._problem.add_variable(name=u('x'))
+
 
 class TestSmallExactProblem(unittest.TestCase):
     def setUp(self):
         self._problem = qsoptex.ExactProblem()
-        self._problem.add_variable(name='x', objective=2, lower=3.5, upper=17.5)
-        self._problem.add_variable(name='y', objective=-1, lower=None, upper=2)
-        self._problem.add_linear_constraint(qsoptex.ConstraintSense.EQUAL, {'x': 1, 'y': 1}, rhs=0)
+        self._problem.add_variable(
+            name='x', objective=2, lower=3.5, upper=17.5)
+        self._problem.add_variable(
+            name='y', objective=-1, lower=None, upper=2)
+        self._problem.add_linear_constraint(
+            qsoptex.ConstraintSense.EQUAL, {'x': 1, 'y': 1}, rhs=0, name='c1')
         self._problem.set_objective_sense(qsoptex.ObjectiveSense.MAXIMIZE)
 
+    def test_add_infinity_variable_bound(self):
+        self._problem.add_variable(
+            name='z1', lower=float('-inf'), upper=10)
+        self._problem.add_variable(
+            name='z2', lower=0, upper=float('inf'))
+
     def test_reaches_status_optimal(self):
         status = self._problem.solve()
         self.assertEqual(status, qsoptex.SolutionStatus.OPTIMAL)
 
     def test_reaches_status_infeasible(self):
         self._problem.add_variable(name='z', lower=200, upper=None)
-        self._problem.add_linear_constraint(qsoptex.ConstraintSense.GREATER, {'y': 1, 'z': -1 }, rhs=0)
+        self._problem.add_linear_constraint(
+            qsoptex.ConstraintSense.GREATER, {'y': 1, 'z': -1}, rhs=0)
         status = self._problem.solve()
         self.assertEqual(status, qsoptex.SolutionStatus.INFEASIBLE)
 
     def test_reaches_status_unbounded(self):
-        self._problem.add_variable(name='z', lower=200, upper=None, objective=1)
+        self._problem.add_variable(
+            name='z', lower=200, upper=None, objective=1)
         status = self._problem.solve()
         self.assertEqual(status, qsoptex.SolutionStatus.UNBOUNDED)
 
@@ -74,12 +90,12 @@ class TestSmallExactProblem(unittest.TestCase):
     def test_solution_value_index_negative(self):
         self._problem.solve()
         with self.assertRaises(IndexError):
-            x = self._problem.get_value(-1)
+            self._problem.get_value(-1)
 
     def test_solution_value_index_too_high(self):
         self._problem.solve()
         with self.assertRaises(IndexError):
-            x = self._problem.get_value(10)
+            self._problem.get_value(10)
 
     def test_get_status_method(self):
         s = self._problem.solve()
@@ -96,10 +112,42 @@ class TestSmallExactProblem(unittest.TestCase):
 
         # Modified problem
         self._problem.add_variable(name='z', objective=1, lower=0, upper=200)
-        self._problem.add_linear_constraint(qsoptex.ConstraintSense.LESS, {'z': 1, 'x': -10 }, rhs=-50)
+        self._problem.add_linear_constraint(
+            qsoptex.ConstraintSense.LESS, {'z': 1, 'x': -10}, rhs=-50)
         self._problem.solve()
 
-        self.assertEqual(self._problem.get_objective_value(), fractions.Fraction('355/2'))
+        self.assertEqual(
+            self._problem.get_objective_value(), fractions.Fraction('355/2'))
+
+    def test_delete_variable(self):
+        self._problem.add_variable(name='z', objective=1, lower=0, upper=1)
+        status = self._problem.solve()
+        self.assertEqual(status, qsoptex.SolutionStatus.OPTIMAL)
+        obj = self._problem.get_objective_value()
+        self.assertEqual(obj, fractions.Fraction('107/2'))
+
+        self._problem.delete_variable('z')
+
+        # Solve problem again without z
+        status = self._problem.solve()
+        self.assertEqual(status, qsoptex.SolutionStatus.OPTIMAL)
+        obj = self._problem.get_objective_value()
+        self.assertEqual(obj, fractions.Fraction('105/2'))
+
+    def test_delete_constraint(self):
+        self._problem.add_linear_constraint(
+            qsoptex.ConstraintSense.LESS, {'x': 1}, rhs=15, name='constr2')
+        status = self._problem.solve()
+        self.assertEqual(status, qsoptex.SolutionStatus.OPTIMAL)
+        self.assertEqual(self._problem.get_value('x'), 15)
+
+        self._problem.delete_linear_constraint('constr2')
+
+        status = self._problem.solve()
+        self.assertEqual(status, qsoptex.SolutionStatus.OPTIMAL)
+        self.assertEqual(
+            self._problem.get_value('x'), fractions.Fraction('35/2'))
+
 
 if __name__ == '__main__':
     unittest.main()
